@@ -35,20 +35,20 @@ extension MAS {
 		}
 
 		private func run(appCatalog: some AppCatalog) async throws {
-			try await run(appStorePageURL: appStorePageURL(appCatalog: appCatalog))
+			try await run(appStorePageURLString: appStorePageURLString(appCatalog: appCatalog))
 		}
 
-		private func run(appStorePageURL: String?) async throws {
-			guard let appStorePageURL else {
+		private func run(appStorePageURLString: String?) async throws {
+			guard let appStorePageURLString else {
 				// If no App Store Page URL was given, just open the MAS GUI app
 				try await openMacAppStore()
 				return
 			}
 
-			try await openMacAppStorePage(forAppStorePageURL: appStorePageURL)
+			try await openMacAppStorePage(forAppStorePageURLString: appStorePageURLString)
 		}
 
-		private func appStorePageURL(appCatalog: some AppCatalog) async throws -> String? {
+		private func appStorePageURLString(appCatalog: some AppCatalog) async throws -> String? {
 			guard let appIDString else {
 				return nil
 			}
@@ -56,32 +56,32 @@ extension MAS {
 			return try await appCatalog.lookup(
 				appID: AppID(from: appIDString, forceBundleID: forceBundleIDOptionGroup.forceBundleID)
 			)
-			.appStorePageURL
+			.appStorePageURLString
 		}
 	}
 }
 
 private func openMacAppStore() async throws {
-	guard let macappstoreSchemeURL = URL(string: "macappstore:") else {
-		throw MASError.runtimeError("Failed to create URL from macappstore scheme")
+	guard let macAppStoreSchemeURL = URL(string: "macappstore:") else {
+		throw MASError.error("Failed to create URL from macappstore scheme")
 	}
 
 	let workspace = NSWorkspace.shared
-	guard let appURL = workspace.urlForApplication(toOpen: macappstoreSchemeURL) else {
-		throw MASError.runtimeError("Failed to find app to open macappstore URLs")
+	guard let appURL = workspace.urlForApplication(toOpen: macAppStoreSchemeURL) else {
+		throw MASError.error("Failed to find app to open macappstore URLs")
 	}
 
 	try await workspace.openApplication(at: appURL, configuration: NSWorkspace.OpenConfiguration())
 }
 
-private func openMacAppStorePage(forAppStorePageURL urlString: String) async throws {
-	guard var urlComponents = URLComponents(string: urlString) else {
-		throw MASError.urlParsing(urlString)
+private func openMacAppStorePage(forAppStorePageURLString appStorePageURLString: String) async throws {
+	guard var urlComponents = URLComponents(string: appStorePageURLString) else {
+		throw MASError.unparsableURL(appStorePageURLString)
 	}
 
 	urlComponents.scheme = masScheme
 	guard let url = urlComponents.url else {
-		throw MASError.urlParsing(String(describing: urlComponents))
+		throw MASError.unparsableURL(String(describing: urlComponents))
 	}
 
 	try await url.open()
