@@ -12,7 +12,7 @@ extension ProcessInfo {
 	var sudoUID: uid_t {
 		get throws {
 			guard let sudoUID = environment["SUDO_UID"].flatMap({ uid_t($0) }) else {
-				throw MASError.runtimeError("Failed to get sudo uid")
+				throw MASError.error("Failed to get sudo uid")
 			}
 
 			return sudoUID
@@ -22,7 +22,7 @@ extension ProcessInfo {
 	var sudoGID: gid_t {
 		get throws {
 			guard let sudoGID = environment["SUDO_GID"].flatMap({ gid_t($0) }) else {
-				throw MASError.runtimeError("Failed to get sudo gid")
+				throw MASError.error("Failed to get sudo gid")
 			}
 
 			return sudoGID
